@@ -1,4 +1,4 @@
-__version__ = '0.4'
+__version__ = '0.4.1'
 
 from .corpora import (
     Subcorpus,
@@ -34,22 +34,6 @@ def set_stream_handlers_level(level) -> None:
     corpora_requests.stream_handler.setLevel(level)
 
 
-def set_file_handlers_level(level) -> None:
-    import rnc.corpora_requests
-
-    examples.file_handler.setLevel(level)
-    corpora.file_handler.setLevel(level)
-    corpora_requests.file_handler.setLevel(level)
-
-
-def set_loggers_level(level) -> None:
-    import rnc.corpora_requests
-
-    examples.logger.setLevel(level)
-    corpora.logger.setLevel(level)
-    corpora_requests.logger.setLevel(level)
-
-
 __all__ = (
     'MainCorpus',
     'Paper2000Corpus',
@@ -73,7 +57,5 @@ __all__ = (
     'TutoringExample',
     'KwicExample',
 
-    'set_loggers_level',
-    'set_file_handlers_level',
     'set_stream_handlers_level'
 )
